@@ -63,7 +63,9 @@ var ShapeLayerFileChooser = new Lang.Class({
         ShapeLayer.SUPPORTED_TYPES.forEach((function(layerClass) {
             let filter = new Gtk.FileFilter();
             [filter, allFilter].forEach(function(f) {
-                layerClass.mimeTypes.forEach(f.add_mime_type.bind(f));
+                layerClass.mimeTypes.forEach(function(type) {
+                    f.add_mime_type(type);
+                });
             });
             filter.set_name(layerClass.displayName);
             this.add_filter(filter);
@@ -150,10 +152,12 @@ var MainWindow = new Lang.Class({
         }).bind(this));
 
         let popover = placeEntry.popover;
-        popover.connect('selected',
-                        this._mapView.grab_focus.bind(this._mapView));
-        this._mapView.view.connect('button-press-event',
-                                   popover.hide.bind(popover));
+        popover.connect('selected', (function() {
+            this._mapView.grab_focus();
+        }).bind(this));
+        this._mapView.view.connect('button-press-event', (function () {
+            popover.hide();
+        }));
         return placeEntry;
     },
 
@@ -483,14 +487,13 @@ var MainWindow = new Lang.Class({
                        'Andreas Nilsson <nisses.mail@home.se>' ],
             authors: [ 'Zeeshan Ali (Khattak) <zeeshanak@gnome.org>',
                        'Mattias Bengtsson <mattias.jc.bengtsson@gmail.com>',
-                       'Jonas Danielsson <jonas@threetimestwo.org>'],
+                       'Jonas Danielsson <jonas@threetimestwo.org>',
+                       'Marcus Lundblad <ml@update.uu.se>'],
             translator_credits: _("translator-credits"),
             /* Translators: This is the program name. */
             program_name: _("Maps"),
             comments: _("A map application for GNOME"),
-            copyright: 'Copyright ' + String.fromCharCode(0x00A9) +
-                       ' 2011' + String.fromCharCode(0x2013) +
-                       '2013 Red Hat, Inc.',
+            copyright: _("Copyright © 2011 – 2017 Red Hat, Inc. and The GNOME Maps authors"),
             license_type: Gtk.License.GPL_2_0,
             logo_icon_name: 'org.gnome.Maps',
             version: pkg.version,
@@ -501,8 +504,9 @@ var MainWindow = new Lang.Class({
             transient_for: this
         });
         aboutDialog.show();
-        aboutDialog.connect('response',
-                            aboutDialog.destroy.bind(aboutDialog));
+        aboutDialog.connect('response', (function() {
+            aboutDialog.destroy();
+        }));
     },
 
     _onOpenShapeLayer: function() {
