@@ -38,7 +38,7 @@ const _MEMORY_CACHE_SIZE_LIMIT = 100; /* number of tiles */
 const _LOGO_PADDING_X = 10;
 const _LOGO_PADDING_Y = 25;
 
-const AttributionLogo = new Lang.Class({
+var AttributionLogo = new Lang.Class({
     Name: 'AttributionLogo',
         Extends: GtkClutter.Actor,
 
