@@ -296,7 +296,7 @@ var MapView = new Lang.Class({
     },
 
     setMapType: function(mapType) {
-        if (this._mapType === mapType)
+        if (this._mapType && this._mapType === mapType)
             return;
 
         let overlay_sources = this.view.get_overlay_sources();
@@ -574,7 +574,9 @@ var MapView = new Lang.Class({
 
         routeLayer = this._createRouteLayer(false, TURN_BY_TURN_ROUTE_COLOR,
                                             ROUTE_LINE_WIDTH);
-        route.path.forEach(routeLayer.add_node.bind(routeLayer));
+        route.path.forEach((function (polyline) {
+            routeLayer.add_node(polyline);
+        }).bind(this));
         this.routingOpen = true;
 
         this._ensureInstructionLayerAboveRouteLayers();
@@ -634,9 +636,14 @@ var MapView = new Lang.Class({
                 routeLayer.add_node(lastPoint);
             }
 
-            if (hasOutline)
-                leg.polyline.forEach(outlineRouteLayer.add_node.bind(outlineRouteLayer));
-            leg.polyline.forEach(routeLayer.add_node.bind(routeLayer));
+            if (hasOutline) {
+                leg.polyline.forEach((function (polyline) {
+                    outlineRouteLayer.add_node(polyline);
+                }));
+            }
+            leg.polyline.forEach((function (polyline) {
+                routeLayer.add_node(polyline);
+            }));
 
             /* like above, "stitch" the route segment with the next one if it's
              * a walking leg, and not the last one */
