@@ -39,9 +39,10 @@ const IMPERIAL_LOCALES = ['unm_US', 'es_US', 'es_PR', 'en_US', 'yi_US'];
 const ACCENTS_REGEX = /[\u0300-\u036F]/g;
 
 let debugInit = false;
-let debugEnabled = false;
 let measurementSystem = null;
 
+var debugEnabled = false;
+
 function debug(msg) {
     if (!debugInit) {
         let env = GLib.getenv('MAPS_DEBUG');
@@ -256,7 +257,7 @@ function _load_icon(icon, loadCompleteCallback) {
 
     icon.load_async(-1, null, function(icon, res) {
         try {
-            let stream = icon.load_finish(res, null)[0];
+            let stream = icon.load_finish(res)[0];
             let pixbuf = GdkPixbuf.Pixbuf.new_from_stream(stream, null);
 
             loadCompleteCallback(pixbuf);
